Документация по m_Librarian — Документация m_Librarian 0.1.2

# Документация по m_Librarian

Здесь должен быть (и, надеюсь, будет) набор программ для индексации библиотек LibRusEc и Флибуста (точнее, zip-файлов из торрентов) и показа содержимого индексов в командной строке, в web-интерфейсе и в графическом интерфейсе.

Contents:

- Прежде чем вы начнёте
  - Программное обеспечение
  - Архивы библиотек
  - Файл конфигурации
  - База данных
- Скрипты командной строки
  - ml-initdb.py
  - ml-import.py
  - ml-search.py
  - ml-web.py
- Новости
  - Version 0.1.2 (2018-05-22)
  - Version 0.1.1 (2018-05-17)
  - Version 0.1.0 (2018-04-25)

# Indices and tables

- Алфавитный указатель
- Состав модуля
- Поиск

# Credits

Автор: Олег Бройтман <phd@phdru.name>.

Copyright (C) 2015-2018 PhiloSoft Design.

# License

GPL.